tsseg.metrics package
=====================

Submodules
----------

tsseg.metrics.base module
-------------------------

.. automodule:: tsseg.metrics.base
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.metrics.change\_point\_detection module
---------------------------------------------

.. automodule:: tsseg.metrics.change_point_detection
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.metrics.gaussian\_f1 module
---------------------------------

.. automodule:: tsseg.metrics.gaussian_f1
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.metrics.bidirectional\_covering module
--------------------------------------------

.. automodule:: tsseg.metrics.bidirectional_covering
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.metrics.state\_detection module
-------------------------------------

.. automodule:: tsseg.metrics.state_detection
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.metrics
   :members:
   :show-inheritance:
   :undoc-members:
